function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var axios = _interopDefault(require('axios'));
var reactToastify = require('react-toastify');
var bs = require('react-icons/bs');
var Querystring = _interopDefault(require('querystring'));
var jwtDecode = _interopDefault(require('jwt-decode'));

var useLocalStorage = function useLocalStorage(key, initialValue) {
  var _useState = React.useState(function () {
      try {
        var item = window.localStorage.getItem(key);
        return item ? JSON.parse(item) : initialValue;
      } catch (error) {
        console.log(error);
        return initialValue;
      }
    }),
    storedValue = _useState[0],
    setStoredValue = _useState[1];
  var setValue = function setValue(value) {
    try {
      var valueToStore = value instanceof Function ? value(storedValue) : value;
      setStoredValue(valueToStore);
      window.localStorage.setItem(key, JSON.stringify(valueToStore));
    } catch (error) {
      console.log(error);
    }
  };
  return [storedValue, setValue];
};

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}
function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;
  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
  return arr2;
}
function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
  if (it) return (it = it.call(o)).next.bind(it);
  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
    if (it) o = it;
    var i = 0;
    return function () {
      if (i >= o.length) return {
        done: true
      };
      return {
        done: false,
        value: o[i++]
      };
    };
  }
  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var ruleRunner = function ruleRunner(field, label) {
  for (var _len = arguments.length, validations = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    validations[_key - 2] = arguments[_key];
  }
  return function (state) {
    for (var _iterator = _createForOfIteratorHelperLoose(validations), _step; !(_step = _iterator()).done;) {
      var v = _step.value;
      var errorMessageFunc = v(state[field], state);
      if (errorMessageFunc) {
        var _ref;
        return _ref = {}, _ref[field] = errorMessageFunc(label), _ref;
      }
    }
    return null;
  };
};
var runValidation = function runValidation(model, runners) {
  return runners.reduce(function (memo, runner) {
    return Object.assign(memo, runner(model));
  }, {});
};
var hasErrors = function hasErrors(validationErrors) {
  for (var key in validationErrors) {
    if (validationErrors.hasOwnProperty(key)) {
      return true;
    }
  }
  return false;
};

var validationHook = (function (initialModel, validationRules, submitHandler) {
  var _useState = React.useState(initialModel),
    model = _useState[0],
    setModel = _useState[1];
  var _useState2 = React.useState(false),
    submitted = _useState2[0],
    setSubmitted = _useState2[1];
  var _useState3 = React.useState(false),
    errors = _useState3[0],
    setErrors = _useState3[1];
  var modelOnChange = function modelOnChange(field, value) {
    var newModel = _extends({}, model);
    newModel[field] = value;
    setModel(newModel);
    setErrors(runValidation(newModel, validationRules));
  };
  function onSubmit(e) {
    e.preventDefault();
    setSubmitted(true);
    var errors = runValidation(model, validationRules);
    setErrors(errors);
    if (!hasErrors(errors)) {
      submitHandler(model);
    }
  }
  return [model, errors, submitted, modelOnChange, onSubmit];
});

var isRequiredMsg = function isRequiredMsg(fieldName) {
  return fieldName + " is required";
};
var mustMatchMsg = function mustMatchMsg(otherFieldName) {
  return function (fieldName) {
    return fieldName + " and " + fieldName + " Must match";
  };
};
var mustDifferMsg = function mustDifferMsg(otherFieldName) {
  return function (fieldName) {
    return fieldName + " and " + otherFieldName + " must differ";
  };
};
var minLengthMsg = function minLengthMsg(length) {
  return function (fieldName) {
    return fieldName + " must be " + length + " lenght";
  };
};
var maxLengthMsg = function maxLengthMsg(length) {
  return function (fieldName) {
    return fieldName + " must not have more than " + length + " characters";
  };
};
var regexMsg = function regexMsg(fieldName) {
  return fieldName + " must match the appropriate pattern";
};
var emailMsg = function emailMsg(fieldName) {
  return fieldName + " must be an email";
};
var minValueMsg = function minValueMsg(fieldName) {
  return function (minValue) {
    return fieldName + " must be greater than " + minValue;
  };
};

var required = function required(text) {
  if (text) {
    return null;
  } else {
    return isRequiredMsg;
  }
};
var mustMatch = function mustMatch(field, fieldName) {
  return function (text, state) {
    return state[field] == text ? null : mustMatchMsg();
  };
};
var mustDiffer = function mustDiffer(field, fieldName) {
  return function (text, state) {
    return state[field] != text ? null : mustDifferMsg(fieldName);
  };
};
var minLength = function minLength(length) {
  return function (text) {
    return (!text ? 0 : text.length) >= length ? null : minLengthMsg(length);
  };
};
var maxLength = function maxLength(length) {
  return function (text) {
    return (!text ? 0 : text.length) <= length ? null : maxLengthMsg(length);
  };
};
var regex = function regex(_regex) {
  return function (text) {
    return _regex.test(text) ? null : regexMsg;
  };
};
var email = function email(text) {
  var re = /^$|^([\w\.\-]+)@([\w\-]+)((\.(\w){2,3})+)$/;
  return re.test(text) ? null : emailMsg;
};
var minValue = function minValue(value) {
  return function (fieldValue) {
    return fieldValue && fieldValue >= value ? null : minValueMsg(value);
  };
};

var rules = {
    __proto__: null,
    required: required,
    mustMatch: mustMatch,
    mustDiffer: mustDiffer,
    minLength: minLength,
    maxLength: maxLength,
    regex: regex,
    email: email,
    minValue: minValue
};

var styles = {"loader":"_styles-module__loader__3qqrl","spin":"_styles-module__spin__1sp4O","loaderContainer":"_styles-module__loaderContainer__zQVVC","error":"_styles-module__error__3fyPz","modal":"_styles-module__modal__Xt-75","modalContent":"_styles-module__modalContent__3bARu","box":"_styles-module__box__37_FJ","boxHeader":"_styles-module__boxHeader__3m_dA","boxContent":"_styles-module__boxContent__1OV3o"};

var ErrorSpanComponent = (function (_ref) {
  var field = _ref.field,
    errors = _ref.errors;
  return !errors[field] || /*#__PURE__*/React__default.createElement("small", {
    className: styles.error
  }, errors[field]);
});

axios.interceptors.request.use(function (config) {
  return config;
}, function (error) {
  return Promise.reject(error);
});
axios.interceptors.response.use(function (response) {
  notify(response.headers);
  return response;
}, function (error) {
  var message = error.response && error.response.data.message ? error.response.data.message : error.message;
  reactToastify.toast.error(message);
  return Promise.reject(error);
});
var notify = function notify(headers) {
  if (headers['x-success-message']) {
    reactToastify.toast.success(headers['x-success-message']);
  }
  if (headers['x-info-message']) {
    reactToastify.toast.info(headers['x-info-message']);
  }
  if (headers['x-warning-message']) {
    reactToastify.toast.warning(headers['x-warning-message']);
  }
};
var updateAuthHeader = function updateAuthHeader(authTokenName, token) {
  var newToken = token || localStorage.getItem(authTokenName);
  if (newToken) {
    localStorage.setItem(authTokenName, newToken);
    axios.defaults.headers = {
      Authorization: "Bearer " + localStorage.getItem(authTokenName)
    };
  }
};
var clearAuthHeader = function clearAuthHeader(authTokenName) {
  localStorage.setItem(authTokenName, "");
};
var request = axios;

function Loader(_ref) {
  var threshold = _ref.threshold,
    isLoading = _ref.isLoading;
  var busy = false;
  var _useState = React.useState(false),
    isVisible = _useState[0],
    setVisible = _useState[1];
  React.useEffect(function () {
    if (isLoading) {
      setTimeout(function () {
        if (busy) {
          setVisible(true);
        }
      }, threshold);
    } else {
      setVisible(false);
      busy = false;
    }
  }, []);
  return isVisible ? /*#__PURE__*/React__default.createElement("div", {
    id: "loader",
    className: styles.loaderContainer
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.loader
  })) : null;
}

var ModalComponent = (function (_ref) {
  var children = _ref.children,
    visible = _ref.visible,
    title = _ref.title,
    onClose = _ref.onClose;
  return visible && /*#__PURE__*/React__default.createElement("div", {
    className: styles.modal
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.modalContent
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.box
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.boxHeader
  }, /*#__PURE__*/React__default.createElement("strong", null, title), /*#__PURE__*/React__default.createElement(bs.BsX, {
    style: {
      cursor: 'pointer',
      "float": 'right',
      paddingBottom: 4
    },
    size: 26,
    onClick: onClose
  }, "x")), /*#__PURE__*/React__default.createElement("div", {
    className: styles.boxContent
  }, children))));
});

var Auth2Service = /*#__PURE__*/function () {
  function Auth2Service(authEndpoint, authTokenName) {
    this.authEndpoint = authEndpoint;
    this.authTokenName = authTokenName;
  }
  var _proto = Auth2Service.prototype;
  _proto.authenticate = function authenticate(clientId, clientSecret, email, password, callback, errorCallback) {
    var _this = this;
    var cliAuthData = clientId + ":" + clientSecret;
    var authData = Querystring.stringify({
      grant_type: 'password',
      username: email,
      password: password,
      scope: ['write', 'read']
    });
    var reqConfig = {
      headers: {
        'content-type': 'application/x-www-form-urlencoded',
        'X-Requested-With': 'XMLHttpRequest',
        Authorization: "Basic " + window.btoa(cliAuthData)
      }
    };
    request.post(this.authEndpoint, authData, reqConfig).then(function (response) {
      localStorage.setItem(_this.authTokenName, response.data.access_token);
      updateAuthHeader(_this.authTokenName, response.data.access_token);
      callback(response);
    }, errorCallback);
  };
  _proto.validateSession = function validateSession() {
    if (!localStorage.getItem(this.authTokenName)) {
      return false;
    }
    var authData = this.getSessionData();
    var date = new Date(0);
    date.setUTCSeconds(authData.exp);
    if (date.valueOf() > new Date().valueOf()) {
      updateAuthHeader(this.authTokenName);
      return true;
    } else {
      return false;
    }
  };
  _proto.getSessionData = function getSessionData() {
    var sessionData = jwtDecode(localStorage.getItem(this.authTokenName));
    return sessionData;
  };
  _proto.signout = function signout(callback) {
    clearAuthHeader(this.authTokenName);
    if (callback) {
      callback();
    }
  };
  return Auth2Service;
}();

var ErrorSpan = ErrorSpanComponent;
var useLocalStorage$1 = useLocalStorage;
var useValidation = validationHook;
var validationRules = rules;
var ruleRunner$1 = ruleRunner;
var hasErrors$1 = hasErrors;
var http = request;
var Loader$1 = Loader;
var updateAuthHeader$1 = updateAuthHeader;
var clearAuthHeader$1 = clearAuthHeader;
var Modal = ModalComponent;
var Auth2Service$1 = Auth2Service;

exports.Auth2Service = Auth2Service$1;
exports.ErrorSpan = ErrorSpan;
exports.Loader = Loader$1;
exports.Modal = Modal;
exports.clearAuthHeader = clearAuthHeader$1;
exports.hasErrors = hasErrors$1;
exports.http = http;
exports.ruleRunner = ruleRunner$1;
exports.updateAuthHeader = updateAuthHeader$1;
exports.useLocalStorage = useLocalStorage$1;
exports.useValidation = useValidation;
exports.validationRules = validationRules;
//# sourceMappingURL=index.js.map
